@@ -1,4 +1,3 @@
-
 ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonicity=c("General"), 
                        Sum_Pi_f = seq(from=0.01, to=0.99, by=.01), M=10000, Volume.Perc=0, Seed=sample(1:100000, size=1)) {   
 
@@ -15,10 +14,9 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
   pi0_1_[pi0_1_==0] <- 1e-20
   pi_0_1[pi_0_1==0] <- 1e-20
   
-  #vector_b <- matrix(data=c(1, pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1), ncol=1)  
-  
   sum_pi_f <- Pi.Vectors <- pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- pi_all <- NULL
   
+#  options(warn=-1)
   if (Monotonicity=="General"){
     
     try(T_No <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("No"), Sum_Pi_f, M, Volume.Perc), silent=TRUE)
@@ -107,17 +105,6 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
                          1, 0, 1, 0, 1, 0, 0), ncol=9)
     A <- cbind(A_r, A_f)
     
-    #restrictions
-    #min_pi_1001 <- min(pi1_0_, pi_0_1)
-    #min_pi_1110 <- min(pi1_1_, pi_1_0)
-    #min_pi_1101 <- min(pi1_0_, pi_1_1)
-    #min_pi_1011 <- min(pi1_1_, pi_0_1)
-    #min_pi_1111 <- min(pi1_1_, pi_1_1)
-    #min_pi_0110 <- min(pi0_1_, pi_1_0)
-    #min_pi_0011 <- min(pi0_1_, pi_0_1)
-    #min_pi_0111 <- min(pi0_1_, pi_1_1)
-    #min_pi_1100 <- min(pi1_0_, pi_1_0)
-    
     pi_1 <- seq(0, 1, by=.01)
     pi_2 <- seq(0, 1, by=.01) 
     pi_3 <- seq(0, 1, by=.01) 
@@ -132,10 +119,6 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
         as.numeric(length(pi_1))*as.numeric(length(pi_2))*as.numeric(length(pi_3))*as.numeric(length(pi_4))*
         as.numeric(length(pi_5))*as.numeric(length(pi_6))*as.numeric(length(pi_7))*as.numeric(length(pi_8))*as.numeric(length(pi_9))
     
-    #if (Volume.Perc==0){
-    #Seed <- round(runif(min=(1+tot_combn_No), max=2147483647, n=1), digits=0)
-    #}
-    
     if (Volume.Perc != 0){M <- tot_combn_No * Volume.Perc}
     
     if (Volume.Perc != 0 & M > 1000000){
@@ -154,20 +137,20 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
            
       for (i in 1: M){
 
-#        if (Volume.Perc==0){Seed <- Seed-1}
-#        if (Volume.Perc!=0){Seed <- Seed+1}
-#        set.seed(Seed)
- 
         Seed <- Seed-1   
         set.seed(Seed)
         
-        
         pi_f <- (RandVec(a=0, b=Sum_Pi_f[k], s=Sum_Pi_f[k], n=9, 1, Seed=Seed))$RandVecOutput  
         
         set.seed(Seed)
         vector_b <- 
           matrix(data=c(1, sample(size = 1, pi1_1_), sample(size = 1, pi1_0_), sample(size = 1, pi_1_1), 
-                        sample(size = 1, pi_1_0), sample(size = 1, pi0_1_), sample(size = 1, pi_0_1)), ncol=1)  
+                        sample(size = 1, pi_1_0), sample(size = 1, pi0_1_), sample(size = 1, pi_0_1)), 
+                        ncol=1)  
+        
+        ch1 <- sum(vector_b[c(2, 3, 6)])
+        ch2 <- sum(vector_b[c(4, 5, 7)])
+        if (((ch1 <=1) & (ch2 <=1)) == TRUE) { 
         
         pi_r <- solve(A_r) %*% (vector_b - (A_f %*% pi_f))
         
@@ -248,13 +231,13 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           theta_S_all <- cbind(theta_S_all, theta_S)
           
           pi_all <- cbind(pi_all, pi) 
-        }
+        }}
       }
     }
     
     num <- dim(R2_H_all)[2]
    
-    if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+    if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data (under no montonicity assumption)."))}
     
     sum_pi_f <- colSums(pi_all[8:16,]) 
     Pi.Vectors <- 
@@ -295,9 +278,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
       tot_combn_T <- 
         as.numeric(length(pi_1))*as.numeric(length(pi_2))*as.numeric(length(pi_3))*as.numeric(length(pi_4))*
         as.numeric(length(pi_5))
-    #if (Volume.Perc==0){
-    #Seed <- round(runif(min=(1+tot_combn_T), max=2147483647, n=1), digits=0)}
-    
+
     if (Volume.Perc != 0){M <- tot_combn_T * Volume.Perc}
     
     if (Volume.Perc != 0 & M > 1000000){
@@ -316,9 +297,6 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     for (k in 1: Sum_Pi_f_number){
       
       for (i in 1: M){
-#       if (Volume.Perc==0){Seed <- Seed-1}
-#        if (Volume.Perc!=0){Seed <- Seed+1}   
-#        set.seed(Seed)
 
         Seed <- Seed-1   
         set.seed(Seed)
@@ -331,6 +309,10 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           matrix(data=c(1, sample(size = 1, pi1_1_), sample(size = 1, pi1_0_), sample(size = 1, pi_1_1), 
                         sample(size = 1, pi_1_0), sample(size = 1, pi0_1_), sample(size = 1, pi_0_1)), ncol=1)  
         
+        ch1 <- sum(vector_b[c(2, 3, 6)])
+        ch2 <- sum(vector_b[c(4, 5, 7)])
+        if (((ch1 <=1) & (ch2 <=1)) == TRUE) { 
+        
         pi_r <-   
           solve(A_star_r) %*% (vector_b - (A_star_f %*% pi_f))
         
@@ -408,14 +390,14 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           
           pi_all <- cbind(pi_all, pi) 
           
-        }
+        }}
       }
     } 
     
     num <- dim(R2_H_all)[2]
     
     
-   if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+   if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data (assuming montonicity for T)."))}
     
     sum_pi_f <- colSums(pi_all[8:12,]) 
     Pi.Vectors <- 
@@ -482,7 +464,10 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
         vector_b <- 
           matrix(data=c(1, sample(size = 1, pi1_1_), sample(size = 1, pi1_0_), sample(size = 1, pi_1_1), 
                         sample(size = 1, pi_1_0), sample(size = 1, pi0_1_), sample(size = 1, pi_0_1)), ncol=1)  
-        
+    
+        ch1 <- sum(vector_b[c(2, 3, 6)])
+        ch2 <- sum(vector_b[c(4, 5, 7)])
+        if (((ch1 <=1) & (ch2 <=1)) == TRUE) {     
         
         pi_r <- solve(A_star_r) %*% (vector_b - (A_star_f %*% pi_f))
         
@@ -561,15 +546,14 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           
           pi_all <- cbind(pi_all, pi) 
           
-          
-        }
+          }}
       }
     }
     
     num <- dim(R2_H_all)[2]
     
    
-      if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+      if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data (assuming montonicity for S)."))}
     
     sum_pi_f <- colSums(pi_all[8:12,]) 
     
@@ -626,6 +610,10 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           matrix(data=c(1, sample(size = 1, pi1_1_), sample(size = 1, pi1_0_), sample(size = 1, pi_1_1), 
                         sample(size = 1, pi_1_0), sample(size = 1, pi0_1_), sample(size = 1, pi_0_1)), ncol=1)  
         
+        ch1 <- sum(vector_b[c(2, 3, 6)])
+        ch2 <- sum(vector_b[c(4, 5, 7)])
+        if (((ch1 <=1) & (ch2 <=1)) == TRUE) { 
+        
         pi_r <-   
           solve(A_star_r) %*% (vector_b - (A_star_f %*% pi_f))
         
@@ -702,14 +690,14 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           
           pi_all <- cbind(pi_all, pi) 
           
-        }
+        }}
       }
     }
     
     num <- dim(R2_H_all)[2]
     
     
-     if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+     if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data (assuming monotonicity for S and T)."))}
   
         
     sum_pi_f <- colSums(pi_all[8:9,]) 
@@ -719,7 +707,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
                               "Pi_1101", "Pi_1111", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f") 
         
   } # end mono S and T
-  
+  options(warn=0)  
  if (exists("tot_combn_No")==FALSE){tot_combn_No <- c(0)}
  if (exists("tot_combn_S")==FALSE){tot_combn_S <- c(0)}
  if (exists("tot_combn_T")==FALSE){tot_combn_T <- c(0)}
